Crate v_utils_macros

Crate v_utils_macros 

Macros

graphemics
returns Vec<String> of the ways to refer to a struct name
make_df

Derive Macros

CompactFormat
cli-like string serialization format, with focus on compactness
MyConfigPrimitives
OptionalFieldsFromVecStr
Put on a struct with optional fields, each of which implements FromStr
ScreamIt
Implements Display and FromStr for variants of an enum, using SCREAMING_SNAKE_CASE
Settings
Derive macro for application settings that integrates config files, environment variables, and CLI flags.
SettingsBadlyNested
NB: assumes that the child struct and the field containing it on parent are named the same (with adjustment for casing).
VecFieldsFromVecStr
WrapNew