#[derive(OptionalFieldsFromVecStr)]Expand description
Put on a struct with optional fields, each of which implements FromStr
BUG: may write to the wrong field, if any of the child structs share the same acronym AND same fields. In reality, shouldn’t happen.